@@ -2,7 +2,7 @@ import numpy as np
 
 
 def update_particle_position_and_direction(
-    position, direction, interaction_range, velocity, noise_magnitude
+    position, direction, global_drift, interaction_range, velocity, noise_magnitude
 ):
     """
     Update the particle positions and directions using the Vicsek model
@@ -10,6 +10,7 @@ def update_particle_position_and_direction(
     Params:
         position: An array of particle positions (A)
         direction: An array of particle directions (radians)
+        global_drift: The global drift (A/time)
         interaction_range: The distance at which particles interact (A)
         velocity: The constant velocity of the system (A/time)
         noise_magnitude: The direction noise magnitude (radians)
@@ -35,9 +36,13 @@ def update_particle_position_and_direction(
         )
     direction = direction_mean + nu
 
+    # Ensure is a numpy array
+    global_drift = np.array(global_drift)
+
     # Compute the new position of the particle
-    position[:, :2] = position[:, :2] + velocity * dt * np.stack(
-        [np.cos(direction), np.sin(direction)], axis=1
+    position[:, :2] = position[:, :2] + dt * (
+        global_drift
+        + velocity * np.stack([np.cos(direction), np.sin(direction)], axis=1)
     )
 
     # Return the position and direction
